<?php

//Custom fields:
require_once get_template_directory() . '/framework/bfi_thumb-master/BFI_Thumb.php';
require_once get_template_directory() . '/framework/meta-boxes.php';
require_once get_template_directory() . '/shortcodes.php';
require_once get_template_directory() . '/framework/theme-options.php';
require_once get_template_directory() . '/framework/theme-options/framework.php';
require_once get_template_directory() . '/framework/wp_bootstrap_navwalker.php';
require_once get_template_directory() . '/framework/DomainAvailability.php';

//Theme Set up:
function servereast_theme_setup() {

   /*

     * Make theme available for translation.

     * Translations can be filed in the /languages/ directory.

     * If you're building a theme based on cubic, use a find and replace

     * to change 'cubic' to the name of your theme in all the template files

     */

    load_theme_textdomain( 'servereast', get_template_directory() . '/languages' );

    /** Set Content width **/
    if ( ! isset( $content_width ) ) 
        $content_width = 900;
    /*
     * This theme uses a custom image size for featured images, displayed on
     * "standard" posts and pages.
     */
	add_theme_support( 'custom-header' ); 
	add_theme_support( 'custom-background' );
	
    add_theme_support( 'post-thumbnails' );
    // Adds RSS feed links to <head> for posts and comments.
    add_theme_support( 'automatic-feed-links' );
    // Switches default core markup for search form, comment form, and comments
    // to output valid HTML5.
    add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
    //Post formats
    add_theme_support( 'post-formats', array(
        'audio',  'gallery', 'image', 'video',
    ) );

	//Tags
	add_theme_support( 'title-tag' );

    // This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
        'primary'   => __('Primary Menu', 'servereast')
	) );
}
add_action( 'after_setup_theme', 'servereast_theme_setup' );

function servereast_load_custom_wp_admin_style() {
        wp_register_style( 'custom_wp_admin_css', get_template_directory_uri() . '/framework/admin-style.css', false, '1.0.0' );
        wp_enqueue_style( 'custom_wp_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'servereast_load_custom_wp_admin_style' );

/*Register Fonts*/
function servereast_theme_fonts_url() {
    $fonts_url = '';
 
    $hind = _x( 'on', 'Hind font: on or off', 'servereast' );
    
    $mon = _x( 'on', 'Montserrat font: on or off', 'servereast' );

    if ( 'off' !== $hind || 'off' !== $mon ) {
        $font_families = array();
 
        if ( 'off' !== $hind ) {
            $font_families[] = 'Hind:400,300,600,500,700&amp;subset=latin,latin-ext';
        }
        if ( 'off' !== $mon ) {
            $font_families[] = 'Montserrat:400,700';
        }
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );

}
/*
Enqueue scripts and styles.
*/
function servereast_theme_scripts() {
    wp_enqueue_style( 'servereast-fonts', servereast_theme_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'servereast_theme_scripts' );

function servereast_theme_scripts_styles() {

	$protocol = is_ssl() ? 'https' : 'http';

    /** All frontend css files **/
    wp_enqueue_style( 'servereast-bootstrap', get_template_directory_uri().'/css/bootstrap.css');
    wp_enqueue_style( 'servereast-bootstrap-theme', get_template_directory_uri().'/css/bootstrap-theme.css');
	wp_enqueue_style( 'servereast-block_grid_bootstrap', get_template_directory_uri().'/css/block_grid_bootstrap.css');
    wp_enqueue_style( 'servereast-owl-car', get_template_directory_uri().'/css/owl.carousel.css');
    wp_enqueue_style( 'servereast-owl-theme', get_template_directory_uri().'/css/owl.theme.css');
    wp_enqueue_style( 'servereast-woocommerce', get_template_directory_uri().'/css/woocommerce.css');
    wp_enqueue_style( 'servereast-animate', get_template_directory_uri().'/css/animate.min.css');  
    wp_enqueue_style( 'servereast-slicknav', get_template_directory_uri().'/css/slicknav.css');
    wp_enqueue_style( 'servereast-table', get_template_directory_uri().'/css/tablesaw.stackonly.css');
    wp_enqueue_style( 'servereast-circliful', get_template_directory_uri().'/css/jquery.circliful.css');
	wp_enqueue_style( 'servereast-font-awesome', get_template_directory_uri().'/css/font-awesome.min.css');
	wp_enqueue_style( 'servereast-style', get_stylesheet_uri(), array(), '21-05-2015' );
		
    /** Js for comment on single post **/    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
    	wp_enqueue_script( 'comment-reply' );
	}

    // Load custom color scheme file
    $color_1 = servereast_theme_option('custom_color_1');
    $color_2 = servereast_theme_option('custom_color_2');
    if ( intval( servereast_theme_option( 'custom_color_scheme' ) ) && ($color_1  || $color_2) ) {

        $upload_dir = wp_upload_dir();
        $dir        = path_join( $upload_dir['baseurl'], 'custom-css' );
        $file       = $dir . '/color-scheme.css';
        wp_enqueue_style( 'servereast-color-scheme', $file, 1.0 );
    }

    /** All frontend js files **/
    wp_enqueue_script("servereast-maps-js", "$protocol://maps.googleapis.com/maps/api/js?key=AIzaSyAvpnlHRidMIU374bKM5-sx8ruc01OvDjI",array('jquery'),false,true);
	wp_enqueue_script("servereast-bootstrap", get_template_directory_uri()."/js/bootstrap.min.js",array('jquery'),false,true);
	wp_enqueue_script("servereast-fitvids", get_template_directory_uri()."/js/jquery.fitvids.js",array('jquery'),false,true);
    wp_enqueue_script("servereast-hoverIntent", get_template_directory_uri()."/js/hoverIntent.js",array('jquery'),false,true);
	wp_enqueue_script("servereast-superfish", get_template_directory_uri()."/js/superfish.min.js",array('jquery'),false,true);
	wp_enqueue_script("servereast-carousel", get_template_directory_uri()."/js/owl.carousel.js",array('jquery'),false,false);
	wp_enqueue_script("servereast-wow", get_template_directory_uri()."/js/wow.min.js",array('jquery'),false,true);
    wp_enqueue_script("servereast-circliful", get_template_directory_uri()."/js/jquery.circliful.min.js",array('jquery'),false,true);
    wp_enqueue_script("servereast-waypoints", get_template_directory_uri()."/js/waypoints.min.js",array('jquery'),false,true);
    wp_enqueue_script("servereast-slicknav", get_template_directory_uri()."/js/jquery.slicknav.min.js",array(),false,true);
    wp_enqueue_script("servereast-retina", get_template_directory_uri()."/js/retina.min.js",array('jquery'),false,true);    
    wp_enqueue_script("servereast-vpsslide", get_template_directory_uri()."/js/jquery-ui.js",array('jquery'),false,true);    
	wp_enqueue_script("servereast-sorter", get_template_directory_uri()."/js/jquery.tablesorter.min.js",array('jquery'),false,true);
	wp_enqueue_script("servereast-custom", get_template_directory_uri()."/js/custom.js",array('jquery'),false,true);
    wp_localize_script( 'servereast-custom', 'wdc_ajax', array(
        'ajaxurl'       => admin_url( 'admin-ajax.php' ),
        'wdc_nonce'     => wp_create_nonce( 'wdc_nonce' ))
    );
}
add_action( 'wp_enqueue_scripts', 'servereast_theme_scripts_styles');

if(!function_exists('servereast_custom_frontend_style')){
	function servereast_custom_frontend_style(){
    $background = servereast_theme_option( 'footer_color' );
    $topfoot = '';
    $bread = '';
    $bread_color = '';
    $bg_css = ! empty( $background['color'] ) ? "{$background['color']}" : '';

  if ( ! empty( $background['image'] ) ) {
   $bg_css .= " url({$background['image']})";
   $bg_css .= " {$background['repeat']}";
   $bg_css .= " {$background['position_x']} {$background['position_y']}";
   $bg_css .= " {$background['attachment']}";
   $bg_css .= ! empty( $background['size'] ) ? " {$background['size']}" : '';
  }
 
  if( ! empty($bg_css)){
    $bg_css = '.footer{background:'.$bg_css.'}';
  }
  if(servereast_theme_option( 'topfooter_color' )){
    $topfoot = '.social{background:'.servereast_theme_option( 'topfooter_color' ).'}';
  }
  if(servereast_theme_option( 'breadcrumb' ) == 0){
    $bread = '.breadcrumbs{display: none;}';
  }
  if(servereast_theme_option( 'bread_color' )){
    $bread_color = '.breadcrumbs{background:'.servereast_theme_option( 'bread_color' ).'}';
  }
  $bg_css .= servereast_theme_option('custom_css');
  $bg_css .= $topfoot;
  $bg_css .= $bread;
  $bg_css .= $bread_color;
  if(! empty($bg_css)){
	echo '<style type="text/css">'.$bg_css.'</style>';
    }
}
}

add_action('wp_head', 'servereast_custom_frontend_style');

//Search Domain
function servereast_wdc_display_func(){
    check_ajax_referer( 'wdc_nonce', 'security' );

if(isset($_POST['domain']))
{
    $domain = str_replace(array('www.', 'http://'), NULL, $_POST['domain']);
    $ext = $_POST['ext'];
    $domain = preg_replace("/[^-a-zA-Z0-9.]+/", "", $domain);
    if(strlen($domain) > 0)
    {
        
        $Domains = new DomainAvailability();
        $available = $Domains->is_available($domain, $ext);
        $custom_found_result_text = __('<i class="fa fa-check"></i>  Congratulations! <b>'.$domain.$ext.'</b> is available!', 'servereast');
        $custom_not_found_result_text = __('<i class="fa fa-check"></i>  Sorry! <b>'.$domain.$ext.'</b> is already taken!', 'servereast');
        $custom_not_found_result_text2 = __('WHOIS server not found for that TLD', 'servereast');
        
        if ($available == '1') {
                $result = array('status'=>1,'domain'=>$domain, 'text'=> '<p class="domain-checker-available">'.$custom_found_result_text.'</p>');
                echo json_encode($result);
        } elseif ($available == '0') {
                $result = array('status'=>0,'domain'=>$domain, 'text'=> '<p class="domain-checker-unavailable">'.$custom_not_found_result_text.'</p>');
                echo json_encode($result);
        }elseif ($available == '2'){
                $result = array('status'=>0,'domain'=>$domain, 'text'=> '<p class="not-available">'.$custom_not_found_result_text2.'</p>');
                echo json_encode($result);
        }
        
    }
    else
    {
        echo 'Please enter the domain name';
    }
}
die();
}
add_action('wp_ajax_wdc_display','servereast_wdc_display_func');
add_action('wp_ajax_nopriv_wdc_display','servereast_wdc_display_func');

// Widget Sidebar
function servereast_widgets_init() {
	register_sidebar( array(
        'name'          => __( 'Primary Sidebar', 'servereast' ),
        'id'            => 'sidebar-1',        
		'description'   => __( 'Appears in the sidebar section of the site.', 'servereast' ),        
		'before_widget' => '<div id="%1$s" class="widget %2$s">',        
		'after_widget'  => '</div>',        
		'before_title'  => '<h3 class="badge">',        
		'after_title'   => '</h3>'
    ) );
    register_sidebar( array(
        'name'          => __( 'Newsletter Widget', 'servereast' ),
        'id'            => 'newsletter',
        'description'   => __( 'Newsletter Widget that appears on the Footer.', 'servereast' ),
        'before_widget' => '<div id="%1$s" class="%2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4>',
        'after_title'   => '</h4>',
    ) );
    register_sidebar( array(
        'name'          => __( 'Shop Sidebar', 'servereast' ),
        'id'            => 'shop-sidebar',        
        'description'   => __( 'Appears in the sidebar shop of the site.', 'servereast' ),        
        'before_widget' => '<div id="%1$s" class="widget %2$s">',        
        'after_widget'  => '</div>',        
        'before_title'  => '<h3 class="badge">',        
        'after_title'   => '</h3>'
    ) );
    register_sidebar( array(
		'name'          => __( 'Footer One Widget Area', 'servereast' ),
		'id'            => 'footer-area-1',
		'description'   => __( 'Footer Widget that appears on the Footer.', 'servereast' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Two Widget Area', 'servereast' ),
		'id'            => 'footer-area-2',
		'description'   => __( 'Footer Widget that appears on the Footer.', 'servereast' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Three Widget Area', 'servereast' ),
		'id'            => 'footer-area-3',
		'description'   => __( 'Footer Widget that appears on the Footer.', 'servereast' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Fourth Widget Area', 'servereast' ),
		'id'            => 'footer-area-4',
		'description'   => __( 'Footer Widget that appears on the Footer.', 'servereast' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );    
 
}
add_action( 'widgets_init', 'servereast_widgets_init' );

function servereast_breadcrumbs() {
    $text['home']     = __('Home', 'servereast'); // text for the 'Home' link
    $text['category'] = '%s'; // text for a category page
    $text['tax']      = '%s'; // text for a taxonomy page
    $text['search']   = '%s'; // text for a search results page
    $text['tag']      = '%s'; // text for a tag page
    $text['author']   = '%s'; // text for an author page
    $text['404']      = '404'; // text for the 404 page
 
    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $showOnHome  = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
    $delimiter   = ''; // delimiter between crumbs
    $before      = '<li class="active">'; // tag before the current crumb
    $after       = '</li>'; // tag after the current crumb
    
 
    global $post;
    $homeLink = home_url('/') . '';
    $linkBefore = '<li>';
    $linkAfter = '</li>';
    $linkAttr = ' rel="v:url" property="v:title"';
    $link = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;
 
    if (is_home() || is_front_page()) {
 
        if ($showOnHome == 1) echo '<div id="crumbs"><a href="' . $homeLink . '">' . $text['home'] . '</a></div>';
 
    } else {
 
        echo '<ol class="breadcrumb">' . sprintf($link, $homeLink, $text['home']) . $delimiter;
 
        
        if ( is_category() ) {
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0) {
                $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo htmlspecialchars_decode( $cats );
            }
            echo htmlspecialchars_decode( $before ) . sprintf($text['category'], single_cat_title('', false)) . htmlspecialchars_decode( $after );
 
        } elseif( is_tax() ){
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0) {
                $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo htmlspecialchars_decode( $cats );
            }
            echo htmlspecialchars_decode( $before ) . sprintf($text['tax'], single_cat_title('', false)) . htmlspecialchars_decode( $after );
        
        }elseif ( is_search() ) {
            echo htmlspecialchars_decode( $before ) . sprintf($text['search'], get_search_query()) . htmlspecialchars_decode( $after );
 
        } elseif ( is_day() ) {
            echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
            echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
            echo htmlspecialchars_decode( $before ) . get_the_time('d') . htmlspecialchars_decode( $after );
 
        } elseif ( is_month() ) {
            echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
            echo htmlspecialchars_decode( $before ) . get_the_time('F') . htmlspecialchars_decode( $after );
 
        } elseif ( is_year() ) {
            echo htmlspecialchars_decode( $before ) . get_the_time('Y') . htmlspecialchars_decode( $after );
 
        } elseif ( is_single() && !is_attachment() ) {
            if ( get_post_type() != 'post' ) {
                $post_type = get_post_type_object(get_post_type());
                $slug = $post_type->rewrite;
                if ( get_post_type() == 'portfolio' ) {
                 printf(''); //Translate breadcrumb.
             }else{
              printf($link, $homeLink . '/' . $slug['slug'] . '/', $post_type->labels->singular_name);
             }
                if ($showCurrent == 1) echo htmlspecialchars_decode( $delimiter ) . $before . get_the_title() . $after;
            } else {
                $cat = get_the_category(); $cat = $cat[0];
                $cats = get_category_parents($cat, TRUE, $delimiter);
                if ($showCurrent == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo htmlspecialchars_decode( $cats );
                if ($showCurrent == 1) echo htmlspecialchars_decode( $before ) . get_the_title() . $after;
            }
 
        } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
            $post_type = get_post_type_object(get_post_type());
            echo htmlspecialchars_decode( $before ) . $post_type->labels->singular_name . htmlspecialchars_decode( $after );
 
        } elseif ( is_attachment() ) {
            $parent = get_post($post->post_parent);
            $cat = get_the_category($parent->ID); $cat = $cat[0];
            $cats = get_category_parents($cat, TRUE, $delimiter);
            $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
            $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
            echo htmlspecialchars_decode( $cats );
            printf($link, get_permalink($parent), $parent->post_title);
            if ($showCurrent == 1) echo htmlspecialchars_decode( $delimiter ) . $before . get_the_title() . $after;
 
        } elseif ( is_page() && !$post->post_parent ) {
            if ($showCurrent == 1) echo htmlspecialchars_decode( $before ) . get_the_title() . $after;
 
        } elseif ( is_page() && $post->post_parent ) {
            $parent_id  = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
                $parent_id  = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            for ($i = 0; $i < count($breadcrumbs); $i++) {
                echo htmlspecialchars_decode( $breadcrumbs[$i] );
                if ($i != count($breadcrumbs)-1) echo htmlspecialchars_decode( $delimiter );
            }
            if ($showCurrent == 1) echo htmlspecialchars_decode( $delimiter ) . $before . get_the_title() . $after;
 
        } elseif ( is_tag() ) {
            echo htmlspecialchars_decode( $before ) . sprintf($text['tag'], single_tag_title('', false)) . $after;
 
        } elseif ( is_author() ) {
             global $author;
            $userdata = get_userdata($author);
            echo htmlspecialchars_decode( $before ) . sprintf($text['author'], $userdata->display_name) . $after;
 
        } elseif ( is_404() ) {
            echo htmlspecialchars_decode( $before ) . $text['404'] . $after;
        }
 
        if ( get_query_var('paged') ) {
            if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() );
            if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() );
        }
 
        echo '</ol>';
 
    }
}


function servereast_socials() {
 $output  = array();
 $socials = array_filter( (array) servereast_theme_option( 'socials' ) );
 
 if ( empty( $socials ) ) {
  return;
 }

 foreach ( (array) $socials as $name => $value ) {
  $display = $name;

  if ( $name == 'google' ) {
   $display = 'google+';
   $name    = 'google-plus';
  } elseif( $name == 'vimeo' ) {
   $name = 'vimeo-square';
  } elseif ( $name == 'mail' ) {
   $name    = 'envelope';
  }

  if ( $name == 'mail' ) {
   $value   = 'mailto:' . esc_attr( $value );
  } else {
   $value = esc_url( $value );
  }

  $output[] = sprintf(
   '<li><a href="%s" class="bb-%s" target="_blank"><i class="fa fa-%s"></i></a></li>',
   $value,
   esc_attr( $name ),
   esc_attr( $name ),
   $display
  );
 }

 if ( $output ) {
  echo implode( "\n\t", $output );
 }
}


/** Custom theme option post excerpt **/
function servereast_excerpt() {

  if(servereast_theme_option('excerpt_length')){
    $limit = servereast_theme_option('excerpt_length');
  }else{
    $limit = 15;
  }
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

/** Excerpt Section Blog Post **/
function servereast_blog_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

//pagination
function servereast_pagination($prev = '<i class="fa fa-angle-double-left"></i>', $next = '<i class="fa fa-angle-double-right"></i>', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }
    $pagination = array(
		'base' 			=> str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
		'format' 		=> '',
		'current' 		=> max( 1, get_query_var('paged') ),
		'total' 		=> $pages,		
        'type'			=> 'list',
		'end_size'		=> 3,
		'mid_size'		=> 3
    );
    $return =  paginate_links( $pagination );
	echo str_replace( "<ul class='page-numbers'>", '', $return );
}

/* Custom form search */
function servereast_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="search-form blogsearch" action="' . home_url( '/' ) . '" >  
    	<input class="form-control" type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="'.__('Search & Press Enter', 'servereast').'" />
    </form>';
    return $form;
}
add_filter( 'get_search_form', 'servereast_search_form' );

/* Custom comment List: */
function servereast_theme_comment($comment, $args, $depth) {    
   $GLOBALS['comment'] = $comment; ?>

    <li class="comment">
        <div class="comment-body">
            <div class="comment-author vcard">
                <?php echo get_avatar($comment,$size='80',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536'); ?>
                <h6><?php printf(__('%s','servereast'), get_comment_author()) ?></h6>
                <div class="comment-time"><a href=""><?php the_time('F d, Y'); ?></a></div>
            </div>
            <div class="comment-meta commentmetadata">
                <?php if ($comment->comment_approved == '0'){ ?>
                     <p><em><?php _e('Your comment is awaiting moderation.','servereast') ?></em></p>
                <?php }else{ ?>
                    <?php comment_text() ?>
                <?php } ?>
                <div class="reply">
                    <span class="comment-reply-link"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></span>
                </div>
            </div>
        </div>
    </li>
   
<?php
}

/**** WooCommerce ****/
if (class_exists('Woocommerce')) {
    add_theme_support( 'woocommerce' );    

    // Display 12 products per page. Goes in functions.php
    add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 );

    // breadcrumb woocommerce
    remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
    add_action('breadcrumb_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}

//Code Visual Compurso.
require_once get_template_directory() . '/vc_shortcode.php';

// Add new Param in Row
if(function_exists('vc_add_param')){

vc_add_param('vc_row',array(
                              "type" => "dropdown",
                              "heading" => __('Fullwidth', 'servereast'),
                              "param_name" => "fullwidth",
                              "value" => array(   
                                                __('No', 'servereast') => 'no',  
                                                __('Yes', 'servereast') => 'yes',                                                                                
                                              ),
                              "description" => __("Select Fullwidth or not, Default: No fullwidth", "servereast"),      
                            ) 
    );
	
// Add new Param in Column	

vc_add_param('vc_column',array(
                              "type" => "dropdown",
                              "heading" => __('Animation', 'servereast'),
                              "param_name" => "animate",
                              "value" => array(
                                __('None', 'servereast') => 'none',
                                __('fade In', 'servereast') => 'fadein',
                                __('fade InUp', 'servereast') => 'fadeinup',  
                                __('fade InDown', 'servereast') => 'fadeindown',                                 
                                __('fade InLeft', 'servereast') => 'fadeinleft',
                                __('fade InRight', 'servereast') => 'fadeinright',
                                __('zoom In', 'servereast') => 'zoomin',                                                                             
                               ),     
                            ) 
    );

vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => __('Animation Time', 'servereast'),
                              "param_name" => "time",
                              "value" => "",
                              'dependency'  => array( 'element' => 'animate', 'value' => array( 'fadein', 'fadeinup', 'fadeindown','fadeinleft', 'fadeinright', 'zoomin' ) ),
                              "description" => __("Input time show column. Example: 0.6", "servereast"),
                            ) 
    );
	
vc_remove_param( "vc_row", "parallax" );
vc_remove_param( "vc_row", "parallax_image" );
vc_remove_param( "vc_row", "full_width" );
vc_remove_param( "vc_row", "full_height" );
vc_remove_param( "vc_row", "video_bg" );
vc_remove_param( "vc_row", "video_bg_parallax" );
vc_remove_param( "vc_row", "content_placement" );
vc_remove_param( "vc_row", "video_bg_url" );
vc_remove_param( "vc_row", "columns_placement" );
vc_remove_param( "vc_row", "gap" );
vc_remove_param( "vc_row", "equal_height" );
vc_remove_param( "vc_row", "parallax_speed_video" );
vc_remove_param( "vc_row", "parallax_speed_bg" );
vc_remove_param( "vc_row", "disable_element" );
vc_remove_element( "vc_basic_grid" );
vc_remove_element( "vc_masonry_grid" );
vc_remove_element( "vc_media_grid" );
vc_remove_element( "vc_masonry_media_grid" );
}
//}

/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.5.0-alpha
 * @author     Thomas Griffin
 * @author     Gary Jones
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'servereast_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function servereast_theme_register_required_plugins() {

    /*
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        // Plugin Download the http://wordpress.org
        array(
            'name'               => 'Meta Box',
            'slug'               => 'meta-box',
            'required'           => true,
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(            
            'name'               => 'WPBakery Visual Composer', // The plugin name.
            'slug'               => 'js_composer', // The plugin slug (typically the folder name).
            'source'             => 'http://oceanthemes.net/plugins-required/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),

        array(
            'name'               => 'Revolution Slider', // The plugin name.
            'slug'               => 'revslider', // The plugin slug (typically the folder name).            
            'source'             => 'http://oceanthemes.net/plugins-required/revslider.zip', // The plugin source.            
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),

        // This is an example of how to include a plugin from a private repo in your theme.

        array(            
            'name'               => 'OT Testimonial', // The plugin name.
            'slug'               => 'ot_testimonial', // The plugin slug (typically the folder name).
            'source'             => get_template_directory_uri() . '/framework/plugins/ot_testimonial.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ),
        array(
            'name'                     => 'Contact Form 7', // The plugin name
            'slug'                     => 'contact-form-7', // The plugin slug (typically the folder name)
            'required'                 => false, // If false, the plugin is only 'recommended' instead of required
        ),
        array(
            'name'                     => 'Newsletter', // The plugin name
            'slug'                     => 'newsletter', // The plugin slug (typically the folder name)
            'required'                 => false, // If false, the plugin is only 'recommended' instead of required
        ),
        array(            
            'name'               => 'One Click Demo Content', // The plugin name.
            'slug'               => 'servereast-demo-content', // The plugin slug (typically the folder name).
            'source'             => 'http://oceanthemes.net/plugins-required/servereast/servereast-demo-content.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ),
        
    );

    /*
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are wrapped in a sprintf(), so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'parent_slug'  => 'themes.php',            // Parent menu slug.
        'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'servereast' ),
            'menu_title'                      => __( 'Install Plugins', 'servereast' ),
            'installing'                      => __( 'Installing Plugin: %s', 'servereast' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'servereast' ),
            'notice_can_install_required'     => _n_noop(
                'This theme requires the following plugin: %1$s.',
                'This theme requires the following plugins: %1$s.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop(
                'This theme recommends the following plugin: %1$s.',
                'This theme recommends the following plugins: %1$s.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop(
                'Sorry, but you do not have the correct permissions to install the %s plugin.',
                'Sorry, but you do not have the correct permissions to install the %s plugins.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop(
                'The following required plugin is currently inactive: %1$s.',
                'The following required plugins are currently inactive: %1$s.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop(
                'The following recommended plugin is currently inactive: %1$s.',
                'The following recommended plugins are currently inactive: %1$s.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop(
                'Sorry, but you do not have the correct permissions to activate the %s plugin.',
                'Sorry, but you do not have the correct permissions to activate the %s plugins.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop(
                'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
                'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
                'servereast'
            ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop(
                'Sorry, but you do not have the correct permissions to update the %s plugin.',
                'Sorry, but you do not have the correct permissions to update the %s plugins.',
                'servereast'
            ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop(
                'Begin installing plugin',
                'Begin installing plugins',
                'servereast'
            ),
            'activate_link'                   => _n_noop(
                'Begin activating plugin',
                'Begin activating plugins',
                'servereast'
            ),
            'return'                          => __( 'Return to Required Plugins Installer', 'servereast' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'servereast' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'servereast' ), // %s = dashboard link.
            'contact_admin'                   => __( 'Please contact the administrator of this site for help.', 'servereast' ),

            'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}
?>